@@ -14,6 +14,10 @@
 #include "ui.h"
 
 #define IMGFILEMAXSIZE	0x40000000	/* 1giga-bytes */
+
+#define IMAGETYPE_ORIGINAL	0		/* ~ՕʉC[W */
+#define IMAGETYPE_ISO		1		/* ISO9660C[W */
+
 typedef struct {
 	DRIVE *drive;
 	FILE *fp;
@@ -21,6 +25,7 @@ typedef struct {
 	int fileindex;
 	DWORD bytecount;
 	int disc_type;
+	int image_type;
 } COPYDRIVE;
 
 typedef struct {
@@ -2138,6 +2143,8 @@ int CopyDisc(DRIVE *reader, DRIVE *writer)
 			return RET_NG;
 		}
 		ret = ExecCopy(&src, &dst);
+		CloseDevice(&src);
+		CloseDevice(&dst);
 	}
 	else{
 		strcpy(tmpfile, GetOption()->temppath);
@@ -2187,12 +2194,11 @@ int CopyDisc(DRIVE *reader, DRIVE *writer)
 		}
 
 		ret = ExecCopy(&src, &dst);	/* Image file => DISC */
+		CloseDevice(&src);
+		CloseDevice(&dst);
 		RemoveImageFile(tmpfile);
 	}
 
-	CloseDevice(&src);
-	CloseDevice(&dst);
-
 	return ret;
 }
 
