@@ -183,7 +183,7 @@ int SendCmd(DRIVE *drive, BYTE *cdb, DWORD buflen, BYTE reqflag)
   drive->cmdcode = cdb[0];
   memset(&sense_data, 0, sizeof(struct request_sense));
   memset(&cgc, 0, sizeof(struct cdrom_generic_command));
-  cgc.timeout = drive->timeout/10;
+  cgc.timeout = drive->timeout*100;
   cgc.buffer = drive->data_buf;
   cgc.buflen = buflen;
 
@@ -206,8 +206,15 @@ int SendCmd(DRIVE *drive, BYTE *cdb, DWORD buflen, BYTE reqflag)
   memcpy(drive->sense_data, &sense_data,
 	 SENSEDATA_SIZE < sizeof(struct request_sense) ?
 	 SENSEDATA_SIZE : sizeof(struct request_sense));
+#if 1
+  if((drive->sense_data[2] & 0x0f) != 0x00 ||
+     drive->sense_data[12] != 0x00 ||
+     drive->sense_data[13] != 0x00)
+    ret = RET_CMDERR;
+#else
   if(ret!=0)
     ret = RET_CMDERR;
+#endif
 
 #ifdef DEBUG
   dump_cgc(&cgc);
